<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 20, 2020
 */

/**
 * Backup Plan class.
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Backups_Plan_Policy_Total extends Model_Backups_Plan_Policy
{
    private $_BackupMachinePolicy;

    /**
     * Policy of type 'policy.protection.total'
     *
     * The "root" policy - other policies, such as backup.machine, are copies
     * of this one with extended settings, etc.
     *
     * Note: this type does NOT include
     * backup settings - Model_Backups_Plan_Policy_BackupMachine is the correct class
     * for backup settings.
     *
     *
     * @param array $policies
     * @param array $context
     */
    public function __construct(array $policies, array $context = null)
    {
        $policy_total = $this->_getPolicyByType($policies, self::TYPE_POLICY_PROTECTION_TOTAL);

        if (empty($policy_total)) {
            throw new Exception_Acronis_BackupPlan_WrongPolicyType('wrong type');
        }

        parent::__construct($policy_total, $context);
        $this->_setBackupMachinePolicy($policies, $context);
    }

    /**
     * @param array $policies
     * @param array $context
     */
    private function _setBackupMachinePolicy(array $policies, array $context = null)
    {
        $backup_machine_policy = $this->_getPolicyByType($policies, self::TYPE_POLICY_BACKUP_MACHINE);

        if ($backup_machine_policy) {
            $this->_BackupMachinePolicy = new Model_Backups_Plan_Policy_BackupMachine($policies, $context);
        }

        if (!isset($this->_BackupMachinePolicy)) {
            IW::getLog()->debug('Acronis: no backup machine policy found related to policy ' . $this->getName(), $policies);
        }
    }

    /**
     * @return Model_Backups_Plan_Policy_BackupMachine
     */
    public function getBackupMachinePolicy()
    {
        return $this->_BackupMachinePolicy;
    }

    /**
     * Check if policy has child policy of type policy.backup.machine
     *
     * @return boolean
     */
    public function hasBackupMachinePolicy(): bool
    {
        return $this->_BackupMachinePolicy !== null;
    }
}
