<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 23, 2021
 */

/**
 * @package InterWorx
 * @subpackage
 */
class BackupAgentTest extends IWorx_Framework_TestCase
{
    /**
     * OBS - takes long!
     * Only run if you have time to kill.
     */

    /**
     * test install backup agent.
     */
    public function testInstallBackupAgent()
    {
        echo __FUNCTION__;

        $BackupAgent = new Model_BackupAgent();
        if ($BackupAgent->isInstalled()) {
            throw new Exception('CANNOT RUN INSTALL TEST - BACKUP AGENT ALREADY INSTALLED');
        }

        $Reply = IW::FC()->routeFromPHP(
            'Ctrl_Nodeworx_Acronis',
            'installBackupAgentCommit',
            array(),
            new NodeWorx(1)
        );

        $this->assertReplySuccessful($Reply);
        $this->assertTrue($BackupAgent->isInstalled());
    }

    /**
     * test uninstall backup agent.
     *
     * @depends testInstallBackupAgent
     */
    public function testUninstallBackupAgent()
    {
        echo __FUNCTION__;

        $BackupAgent = new Model_BackupAgent();
        if (!$BackupAgent->isInstalled()) {
            throw new Exception('CANNOT RUN UNINSTALL TEST - BACKUP AGENT NOT INSTALLED');
        }

        $Reply = IW::FC()->routeFromPHP(
            'Ctrl_Nodeworx_Acronis',
            'uninstallBackupAgentCommit',
            array(),
            new NodeWorx(1)
        );

        $this->assertReplySuccessful($Reply);
        $this->assertFalse($BackupAgent->isInstalled());
    }
}
