<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 04, 2021
 */

/**
 * Test suite for acronis exceptions. Should return correct sw and nw lang keys.
 *
 * @package InterWorx
 * @subpackage
 */
class AcronisExceptionTest extends IWorx_Framework_TestCase
{
    /**
     * Test Exception_Acronis_ApiFailure
     */
    public function testApiFailure()
    {
        $SUT = new Exception_Acronis_ApiFailure(array(), '/bc/some/endpoint');
        $expected = '##LG_ACRONIS_API_FAILURE##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_AccountDoesNotExist
     */
    public function testAccountDoesNotExist()
    {
        $SUT = new Exception_Acronis_AccountDoesNotExist('account');
        $expected = '##LG_ACRONIS_NO_BACKUP##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_Exception_Acronis_BackupPlan_Missing
     */
    public function testBackupPlanMissing()
    {
        $SUT = new Exception_Acronis_BackupPlan_Missing();
        $expected = '##LG_ACRONIS_INTERNAL_ERROR##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_BackupPlan_NoneAssigned
     */
    public function testBackupPlanNoneAssigned()
    {
        $SUT = new Exception_Acronis_BackupPlan_NoneAssigned();
        $expected = '##LG_ACRONIS_NO_PLAN_ASSIGNED##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_BackupPlan_NoPlanAssigned
     */
    public function testBackupPlanNoPlansAssigned()
    {
        $SUT = new Exception_Acronis_BackupPlan_NoPlanAssigned();
        $expected = '##LG_ACRONIS_NO_PLAN_ASSIGNED##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }


    /**
     * Test Exception_Acronis_DbNotFound
     */
    public function testDbNotFound()
    {
        $SUT = new Exception_Acronis_DbNotFound('nodb');
        $expected = '##LG_ACRONIS_NO_DB##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_DbRecoveryInProgress
     */
    public function testDbRecoveryInProgress()
    {
        $SUT = new Exception_Acronis_DbRecoveryInProgress();
        $expected = '##LG_AB_DB_RECOVERY_ALREADY_IN_PROGRESS##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);
        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_DbRecoveryNotEnabled
     */
    public function testDbRecoveryNotEnabled()
    {
        $SUT = new Exception_Acronis_DbRecoveryNotEnabled();
        $expected = '##LG_DB_RECOVERY_NOT_ENABLED##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_InvalidPath
     */
    public function testInvalidPath()
    {
        $SUT = new Exception_Acronis_InvalidPath('/some/path');
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);
        $expected = '##LG_ACRONIS_INVALID_PATH##';
        $this->assertEquals($expected, $actual);
    }


    /**
     * Test Exception_Acronis_InvalidPath
     */
    public function testInvalidCache()
    {
        $SUT = new Exception_Acronis_InvalidCache();
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);
        $expected = '##LG_ACRONIS_INTERNAL_ERROR##';
        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_InvalidInput
     */
    public function testInvalidInput()
    {
        $SUT = new Exception_Acronis_InvalidInput('input');
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $expected = '##LG_ACRONIS_INVALID_INPUT##';
        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_InvalidCredentials
     */
    public function testInvalidCredentials()
    {
        $SUT = new Exception_Acronis_InvalidCredentials();
        $expected = '##LG_ACRONIS_NOT_AUTHORIZED##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }


    /**
     * Test Exception_Acronis_InvalidRequestConfig
     */
    public function testInvalidRequestConfig()
    {
        $SUT = new Exception_Acronis_InvalidRequestConfig();
        $expected = '##LG_ACRONIS_INTERNAL_ERROR##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_ResumeRecovery
     */
    public function testResumeRecovery()
    {
        $SUT = new Exception_Acronis_ResumeRecovery('started');
        $expected = '##LG_ACRONIS_RESUME_RECOVERY_ERROR##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }

    /**
     * Test Exception_Acronis_RestoreInProgress
     */
    public function testRestoreInProgress()
    {
        $SUT = new Exception_Acronis_RestoreInProgress();
        $expected = '##LG_ACRONIS_ERROR_RESTORE_IN_PROGRESS##';
        $errorCode = $SUT->getErrorCode();
        $actual = AcronisReply::getErrorLangKey($errorCode);

        $this->assertEquals($expected, $actual);
    }
}
