<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 06, 2021
 */

/**
 * @package InterWorx
 * @subpackage
 */
class dbinfotest extends IWorx_Framework_TestCase
{
    const JSON =  "/home/.acronis_tmp/pre-acronis-mysql/dbinfosw.json";
    const PATH_PHP = "/home/interworx/bin/php";

    /**
     * remove json if any
     */
    public function setUp()
    {
        $this->_createDbs();
    }

    /**
     * Create dbs
     */
    private function _createDbs()
    {
        $runDbsBin = self::PATH_PHP . " /home/interworx/plugins/acronis/bin/acronisdbseeder.php --createAccountAndDatabases";
        IWorxExec::exec($runDbsBin);
    }

    /**
     * remove json after each test
     */
    public function tearDown()
    {
        $this->_removeJson();
    }

    /**
     * Remove json file that bin script generates.
     */
    private function _removeJson()
    {
        if ($this->_jsonExists()) {
            $this->_deleteFile(self::JSON);
        }
    }

    /**
     * @param string $filePath
     */
    private function _deleteFile($filePath)
    {
        $deleteJson = "rm -rf $filePath";
        $Command = new Command($deleteJson);
        $Command->runAsRoot();
        $Command->exec();
        if (!$Command->wasSuccessful()) {
            echo "COMMAND NOT SUCCESSFUL $deleteJson";
        }
    }


    /**
     * Test generateJsonSw
     *
     * Should create json with db info
     */
    public function testGenerateJsonSw()
    {
        // make sure script generates json file at expected location
        $this->assertFalse($this->_jsonExists());

        $script = "/home/interworx/plugins/acronis/bin/acronisdbinfo.php";
        $Command = new Command(self::PATH_PHP . " $script --generateJsonSw");
        $Command->exec();

        $this->assertTrue($this->_jsonExists());

        $content = IWorx_Json::readFromFile(self::JSON, true);

        foreach ($content as $db) {
            // make sure json contains expected keys
            $this->assertArrayHasKey('name', $db);
            $this->assertArrayHasKey('size', $db);
            $this->assertArrayHasKey('host', $db);
            $this->assertArrayHasKey('unixuser', $db);
            $this->assertArrayHasKey('dumps_path', $db);
            $this->assertArrayHasKey('unit', $db);

            // make sure "size" is numeric and unit is bytes
            $this->assertTrue(is_numeric($db['size']));
            $this->assertSame('bytes', $db['unit']);
        }
    }

    /**
     * @return boolean
     */
    private function _jsonExists()
    {
        return Model_AcronisFileSys::isFile(self::JSON);
    }
}
