<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Jul 23, 2021
 */

require_once(__DIR__ . './../../../Model/Cache/Prescript.php');
/**
 * @package InterWorx
 * @subpackage
 */
class Cache_PrescriptTest extends IWorx_Framework_TestCase
{
    private $_timestamp;
    private $_unmappedFolder = 'unmapped';
    private $_SUT;

    private $_mappedDatabases = array(
        array(
            'name' => 'mapped',
            'unixuser' => 'unix'
        )
    );

    private $_unmappedDatabases = array(
        array(
            'name' => 'unmapped'
        )
    );

    private $_unixusers = array(
        'unix'
    );



    /**
     * Create SUT & add to cache
     */
    public function setUp()
    {
        $this->_timestamp = time();
        $this->_SUT = new Model_Cache_Prescript();
    }

    /**
     * Delete test item from cache
     */
    public function tearDown()
    {
        $this->_getSut()->delete($this->_timestamp);
    }

    /**
     * test add.
     */
    public function testAdd()
    {
        $SUT = $this->_getSut();
        $SUT->add($this->_timestamp, $this->_getPrescriptData());

        $actual = $SUT->get($this->_timestamp);

        $this->assertArrayHasKey($SUT::TIMESTAMP, $actual);
        $this->assertArrayHasKey($SUT::DATE, $actual);
        $this->assertArrayHasKey($SUT::UNMAPPED_DATABASES, $actual);
        $this->assertArrayHasKey($SUT::MAPPED_DATABASES, $actual);

        $this->assertEquals($this->_timestamp, $actual[$SUT::TIMESTAMP]);
        $this->assertEquals(Model_Acronis::getDateString($this->_timestamp), $actual[$SUT::DATE]);
    }

    /**
     * @return array
     */
    private function _getPrescriptData()
    {
        return array(
            Model_Cache_Abstract::MAPPED_DATABASES => $this->_mappedDatabases,
            Model_Cache_Abstract::UNMAPPED_DATABASES => $this->_unmappedDatabases,
            Model_Cache_Abstract::SW_USERS => $this->_unixusers,
            Model_Cache_Abstract::TIMESTAMP => $this->_timestamp,
            Model_Cache_Abstract::DUMPS_DIR_UNMAPPED => $this->_unmappedFolder,
            Model_Cache_Abstract::DATE => Model_Acronis::getDateString($this->_timestamp)
        );
    }

    /**
     * @return Model_Cache_Prescript
     */
    private function _getSut()
    {
        return $this->_SUT;
    }
}
